SystemOrganization addCategory: #'Ring-Tests-Containers'!

TestCase subclass: #RGNamespaceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Containers'!

!RGNamespaceTest methodsFor: 'testing' stamp: 'VeronicaUquillas 7/29/2011 10:37'!
testCreatingNamespace
	| newNamespace newPackage newClass |
	
	newNamespace := RGFactory current createNamespaceNamed: #'RingNamespace'.
	newPackage := RGFactory current createPackageNamed: #'Collections-Sequenceable'.
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newPackage addClass: newClass.
	newNamespace addPackage: newPackage;
		addClass: newClass.
	
	self assert: (newNamespace isNamespace).
	self assert: ((newNamespace packageNamed: #'Collections-Sequenceable') == newPackage).
	self assert: ((newNamespace classNamed: #OrderedCollection) == newClass).
	self assert: (newNamespace methods isEmpty).
	self assert: (newNamespace pools isEmpty).
	self assert: (newNamespace globalVariables isEmpty).
	
	newNamespace removeClass: newClass.
	self assert: ((newNamespace classNamed: #OrderedCollection) isNil).
	self assert: ((newPackage classNamed: #OrderedCollection) notNil).! !

TestCase subclass: #RGPackageTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Containers'!

!RGPackageTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 17:22'!
testAddingClass
	| newPackage newClass |
	
	newPackage:= RGFactory current createPackageNamed: #'Collections-Sequenceable'.
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newPackage addClass: newClass.
	
	self assert: (newPackage hasClasses).
	self assert: (newClass package == newPackage).
	self assert: ((newPackage classNamed: #OrderedCollection) == newClass)! !

!RGPackageTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 17:22'!
testAddingPackage
	| newPackage childPackage |
	
	newPackage:= RGFactory current createPackageNamed: #'Collections'.
	newPackage addPackageNamed: #'Collections-Sequenceable'.
		
	self assert: (newPackage includesPackageNamed: #'Collections-Sequenceable').
	self assert: (newPackage packages size = 1).
	
	childPackage:= newPackage packageNamed: #'Collections-Sequenceable'.
	self assert: (childPackage parent = newPackage parent).
	self assert: (childPackage package = newPackage).! !

!RGPackageTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 17:22'!
testNewPackage
	| newPackage |
	
	newPackage:= RGFactory current createPackageNamed: 'Collections-Sequenceable'.
	
	self assert: (newPackage isPackage).
	self assert: (newPackage name = 'Collections-Sequenceable').
	self assert: (newPackage classes isEmpty).
	self assert: (newPackage traits isEmpty).
	self assert: (newPackage packages isEmpty).
	self assert: (newPackage package isNil).
	self assert: (newPackage parent == Smalltalk globals).! !

TestCase subclass: #RGSliceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Ring-Tests-Containers'!

!RGSliceTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 17:26'!
testAddingClasses
	| newSlice newClass newTrait newClass2 |
	
	newSlice:= RGFactory current createSliceNamed: 'Foo'.
	newClass:= RGFactory current createClassNamed: #OrderedCollection.
	newTrait:= RGFactory current createTraitNamed: #TSortable.
	
	newSlice addClassNamed: #SortedCollection;
			 addClass: newClass;
			 addTrait: newTrait.
	
	self assert: (newSlice classes size = 3).
	self assert: (newSlice traits size = 1).
	self assert: (newSlice includesClassNamed: #OrderedCollection).
	self assert: ((newSlice classNamed: #OrderedCollection) == newClass).
	self assert: ((newSlice traitNamed: #TSortable) == newTrait).
	self assert: (newClass isIncludedInContainer: newSlice).
	self assert: (newTrait isIncludedInContainer: newSlice).
	self assert: (newSlice allClasses size = 3).
	self assert: (newSlice allTraits size = 1).
	self assert: (newClass parent = newSlice).
	self assert: (newClass rootEnvironment = newSlice environment)! !

!RGSliceTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 17:26'!
testNestingContainers
	| newSlice newSlice2 newClass newTrait newClass2 |
	
	newSlice:= RGFactory current createSliceNamed: #Root.
	newSlice2:= RGFactory current createSliceNamed: #Child.
	newSlice2 environment: newSlice.
	
	newSlice addClassNamed: #OrderedCollection.
	newClass:= newSlice classNamed: #OrderedCollection.
	newSlice addTraitNamed: #TSortable.
	newTrait:= newSlice traitNamed: #TSortable.
	newSlice2 addClassNamed: #SortedCollection.
	newClass2:= newSlice classNamed: #SortedCollection.
	
	self assert: (newSlice classes size = 2).
	self assert: (newSlice2 classes size = 1).
	self assert: (newSlice2 environment = newSlice).
	self assert: (newSlice2 rootEnvironment = newSlice environment)! !

!RGSliceTest methodsFor: 'testing' stamp: 'VeronicaUquillas 4/28/2011 17:26'!
testNewSlice
	| newSlice |
	
	newSlice:= RGFactory current createSliceNamed: 'Foo'.
	
	self assert: (newSlice isSlice).
	self assert: (newSlice classes isEmpty).
	self assert: (newSlice environment == Smalltalk globals)! !
